@@ -91,7 +91,7 @@ class ArgumentsProcessor(object):
     """
 
     __author__ = 'James Johnson'
-    __version__ = '1.1.5'
+    __version__ = '1.1.6'
 
     supplied_arguments = {}
     expected_arguments = {}
@@ -126,20 +126,36 @@ class ArgumentsProcessor(object):
             self.supplied_arguments = supplied_arguments
 
     def validate_supplied_arguments(self):
+     #TODO: break into 3 functions, needs to handle not required items but will not add items not expected
         for (expected_argument_key, expected_argument_value) in self.expected_arguments.items():
-            for (supplied_argument_key, supplied_argument_value) in self.supplied_arguments.items():
-                if supplied_argument_key == expected_argument_key:
-                    if self.validate_by_rules(expected_argument_value, supplied_argument_value):
-                        return True
+            if expected_argument_key in self.supplied_arguments:
+                if self.validate_by_rules(expected_argument_value, self.supplied_arguments[expected_argument_key]):
+                    return True
+                else:
                     return False
+            elif self.is_required(expected_argument_value):
                 return False
 
+    def is_required(self, expected_argument_value):
+        print(expected_argument_value['required'])
+        return expected_argument_value['required']
+
     def validate_by_rules(self, expected_argument_value, supplied_argument_value):
-        if expected_argument_value['required'] == True:
+        if self.is_required(expected_argument_value):
             if self.check_supplied_argument_value_is_not_none_or_empty(supplied_argument_value):
-                return True
-            return False
-        return False
+                if self.check_supplied_argument_value_is_expected(expected_argument_value, supplied_argument_value):
+                    return True
+                else:
+                    return False
+            else:
+                return False
+        else:
+            if self.check_supplied_argument_value_is_expected(expected_argument_value, supplied_argument_value):
+                    return True
+            else:
+                print(supplied_argument_value)
+                print(expected_argument_value['arguments'])
+                return False
 
     def check_supplied_argument_value_is_not_none_or_empty(self, supplied_argument_value):
         if supplied_argument_value is None:
@@ -148,6 +164,12 @@ class ArgumentsProcessor(object):
             return False
         return True
 
+    def check_supplied_argument_value_is_expected(self, expected_argument_value, supplied_argument_value):
+        if supplied_argument_value in expected_argument_value['arguments']:
+            return True
+        else:
+            return False
+
     def process_arguments(self):
-        for expeceted_argument_key in self.expected_arguments:
-            self.return_arguments[expeceted_argument_key] = self.supplied_arguments[expeceted_argument_key]
+        for expected_argument_key in self.expected_arguments:
+            self.return_arguments[expected_argument_key] = self.supplied_arguments[expected_argument_key]
