@@ -3,9 +3,13 @@
 
 __author__ = 'James Johnson'
 
+import rollbar
+import argumentsprocessor.rollbar_cfg as rollbar_cfg
 
 class ArgumentsProcessorException(Exception):
     def __init__(self, msg):
+        rollbar.init(rollbar_cfg.token, rollbar_cfg.environment)  # access_token, environment
+        rollbar.report_message(msg, 'error')
         Exception.__init__(self, msg)
 
 
